@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2005-2016 Marius L. Jøhndal
+  Copyright (C) 2005-2017 Marius L. Jøhndal
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -82,6 +82,8 @@ static void _item_iterator(const void *user_data, int i, const xmlNode *node)
 
   if (mrss_content || encl) {
     f->items[i]->enclosure = (enclosure *)malloc(sizeof(struct _enclosure));
+
+    /* Set default values */
     f->items[i]->enclosure->url = NULL;
     f->items[i]->enclosure->length = 0;
     f->items[i]->enclosure->type = NULL;
@@ -103,6 +105,10 @@ static void _item_iterator(const void *user_data, int i, const xmlNode *node)
       if (!f->items[i]->enclosure->type)
         f->items[i]->enclosure->type = libxmlutil_dup_attr(encl, "type");
     }
+
+    /* Clean up garbage values from the feed */
+    if (f->items[i]->enclosure->length < 0)
+      f->items[i]->enclosure->length = 0;
   } else
     f->items[i]->enclosure = NULL;
 
@@ -196,8 +202,8 @@ static xmlEntityPtr _get_entity(void *ctxt, const xmlChar *name)
       entity = (xmlEntityPtr)g_new0(xmlEntity, 1);
       entity->type = XML_ENTITY_DECL;
       entity->name = name;
-      entity->orig = (xmlChar *)contents;
-      entity->content = (xmlChar *)contents;
+      entity->orig = contents;
+      entity->content = contents;
       entity->length = g_utf8_strlen(contents, -1);
       entity->etype = XML_INTERNAL_PREDEFINED_ENTITY;
     }
